@@ -72,7 +72,7 @@ private Q_SLOTS:
         QCOMPARE(endRemoveRowsSpy.count(), 0);
         QCOMPARE(dataChangedSpy.count(), 0);
 
-        musicDb.insertTracksList(mNewTracks, mNewCovers);
+        musicDb.insertTracksList(mNewTracks);
 
         QCOMPARE(beginInsertRowsSpy.count(), 0);
         QCOMPARE(endInsertRowsSpy.count(), 0);
@@ -139,7 +139,7 @@ private Q_SLOTS:
         QCOMPARE(endRemoveRowsSpy.count(), 0);
         QCOMPARE(dataChangedSpy.count(), 0);
 
-        musicDb.insertTracksList(mNewTracks, mNewCovers);
+        musicDb.insertTracksList(mNewTracks);
 
         QCOMPARE(beginInsertRowsSpy.count(), 0);
         QCOMPARE(endInsertRowsSpy.count(), 0);
@@ -220,7 +220,7 @@ private Q_SLOTS:
             newFiles.push_back(oneTrack.resourceURI());
         }
 
-        musicDb.insertTracksList(mNewTracks, mNewCovers);
+        musicDb.insertTracksList(mNewTracks);
 
         QCOMPARE(beginInsertRowsSpy.count(), 0);
         QCOMPARE(endInsertRowsSpy.count(), 0);
@@ -253,7 +253,7 @@ private Q_SLOTS:
                 QUrl::fromLocalFile(QStringLiteral("album1")), 5, true,
         {}, QStringLiteral("composer1"), QStringLiteral("lyricist1"), false};
 
-        musicDb.insertTracksList({newTrack}, mNewCovers);
+        musicDb.insertTracksList({newTrack});
 
         QCOMPARE(albumsModel.rowCount(), 5);
         QCOMPARE(beginInsertRowsSpy.count(), 2);
@@ -274,7 +274,7 @@ private Q_SLOTS:
                 QUrl::fromLocalFile(QStringLiteral("album1")), 5, true,
         {}, QStringLiteral("composer1"), QStringLiteral("lyricist1"), false};
 
-        musicDb.insertTracksList({secondNewTrack}, mNewCovers);
+        musicDb.insertTracksList({secondNewTrack});
 
         QCOMPARE(albumsModel.rowCount(), 6);
         QCOMPARE(beginInsertRowsSpy.count(), 3);
@@ -322,7 +322,7 @@ private Q_SLOTS:
             newFiles.push_back(oneTrack.resourceURI());
         }
 
-        musicDb.insertTracksList(mNewTracks, mNewCovers);
+        musicDb.insertTracksList(mNewTracks);
 
         QCOMPARE(beginInsertRowsSpy.count(), 0);
         QCOMPARE(endInsertRowsSpy.count(), 0);
@@ -356,7 +356,7 @@ private Q_SLOTS:
                 QUrl::fromLocalFile(QStringLiteral("album1")), 5, true,
         {}, QStringLiteral("composer1"), QStringLiteral("lyricist1"), false};
 
-        musicDb.insertTracksList({modifiedTrack}, mNewCovers);
+        musicDb.insertTracksList({modifiedTrack});
 
         QCOMPARE(albumsModel.rowCount(), 4);
         QCOMPARE(beginInsertRowsSpy.count(), 1);
@@ -407,7 +407,7 @@ private Q_SLOTS:
         QCOMPARE(endRemoveRowsSpy.count(), 0);
         QCOMPARE(dataChangedSpy.count(), 0);
 
-        musicDb.insertTracksList(mNewTracks, mNewCovers);
+        musicDb.insertTracksList(mNewTracks);
 
         QCOMPARE(beginInsertRowsSpy.count(), 1);
         QCOMPARE(endInsertRowsSpy.count(), 1);
@@ -468,7 +468,7 @@ private Q_SLOTS:
         QCOMPARE(endRemoveRowsSpy.count(), 0);
         QCOMPARE(dataChangedSpy.count(), 0);
 
-        musicDb.insertTracksList(mNewTracks, mNewCovers);
+        musicDb.insertTracksList(mNewTracks);
 
         QCOMPARE(beginInsertRowsSpy.count(), 1);
         QCOMPARE(endInsertRowsSpy.count(), 1);
@@ -536,7 +536,7 @@ private Q_SLOTS:
         QCOMPARE(endRemoveRowsSpy.count(), 0);
         QCOMPARE(dataChangedSpy.count(), 0);
 
-        musicDb.insertTracksList(mNewTracks, mNewCovers);
+        musicDb.insertTracksList(mNewTracks);
 
         QCOMPARE(beginInsertRowsSpy.count(), 1);
         QCOMPARE(endInsertRowsSpy.count(), 1);
@@ -555,7 +555,7 @@ private Q_SLOTS:
         auto newTracks = DataTypes::ListTrackDataType();
         newTracks.push_back(newTrack);
 
-        musicDb.insertTracksList(newTracks, mNewCovers);
+        musicDb.insertTracksList(newTracks);
 
         QCOMPARE(beginInsertRowsSpy.count(), 2);
         QCOMPARE(endInsertRowsSpy.count(), 2);
@@ -607,7 +607,7 @@ private Q_SLOTS:
             newFiles.push_back(oneTrack.resourceURI());
         }
 
-        musicDb.insertTracksList(mNewTracks, mNewCovers);
+        musicDb.insertTracksList(mNewTracks);
 
         QCOMPARE(beginInsertRowsSpy.count(), 1);
         QCOMPARE(endInsertRowsSpy.count(), 1);
@@ -624,11 +624,7 @@ private Q_SLOTS:
         {QUrl::fromLocalFile(QStringLiteral("file://image$23"))}, 5, true,
         {}, QStringLiteral("composer1"), QStringLiteral("lyricist1"), false};
 
-        auto newCover = QUrl::fromLocalFile(QStringLiteral("album5"));
-        auto newCovers = QHash<QString, QUrl>();
-        newCovers[QStringLiteral("album5")] = newCover;
-
-        musicDb.insertTracksList({newTrack}, newCovers);
+        musicDb.insertTracksList({newTrack});
 
         QCOMPARE(beginInsertRowsSpy.count(), 2);
         QCOMPARE(endInsertRowsSpy.count(), 2);
@@ -674,7 +670,7 @@ private Q_SLOTS:
         QCOMPARE(endRemoveRowsSpy.count(), 0);
         QCOMPARE(dataChangedSpy.count(), 0);
 
-        musicDb.insertTracksList(mNewTracks, mNewCovers);
+        musicDb.insertTracksList(mNewTracks);
 
         QCOMPARE(beginInsertRowsSpy.count(), 1);
         QCOMPARE(endInsertRowsSpy.count(), 1);
@@ -693,7 +689,7 @@ private Q_SLOTS:
         auto newTracks = DataTypes::ListTrackDataType();
         newTracks.push_back(newTrack);
 
-        musicDb.insertTracksList(newTracks, mNewCovers);
+        musicDb.insertTracksList(newTracks);
 
         QCOMPARE(beginInsertRowsSpy.count(), 1);
         QCOMPARE(endInsertRowsSpy.count(), 1);
@@ -778,7 +774,7 @@ private Q_SLOTS:
         QCOMPARE(endRemoveRowsSpy.count(), 0);
         QCOMPARE(dataChangedSpy.count(), 0);
 
-        musicDb.insertTracksList(mNewTracks, mNewCovers);
+        musicDb.insertTracksList(mNewTracks);
 
         QCOMPARE(beginInsertRowsSpy.count(), 1);
         QCOMPARE(endInsertRowsSpy.count(), 1);
@@ -798,7 +794,7 @@ private Q_SLOTS:
         auto newTracks = DataTypes::ListTrackDataType();
         newTracks.push_back(newTrack);
 
-        musicDb.insertTracksList(newTracks, mNewCovers);
+        musicDb.insertTracksList(newTracks);
 
         QCOMPARE(beginInsertRowsSpy.count(), 2);
         QCOMPARE(endInsertRowsSpy.count(), 2);
@@ -844,7 +840,7 @@ private Q_SLOTS:
         QCOMPARE(endRemoveRowsSpy.count(), 0);
         QCOMPARE(dataChangedSpy.count(), 0);
 
-        musicDb.insertTracksList(mNewTracks, mNewCovers);
+        musicDb.insertTracksList(mNewTracks);
 
         QCOMPARE(albumsModel.rowCount(), 5);
         QCOMPARE(beginInsertRowsSpy.count(), 1);
@@ -905,7 +901,7 @@ private Q_SLOTS:
         QCOMPARE(endRemoveRowsSpy.count(), 0);
         QCOMPARE(dataChangedSpy.count(), 0);
 
-        musicDb.insertTracksList(mNewTracks, mNewCovers);
+        musicDb.insertTracksList(mNewTracks);
 
         QCOMPARE(albumsModel.rowCount(), 5);
         QCOMPARE(beginInsertRowsSpy.count(), 1);
@@ -971,7 +967,7 @@ private Q_SLOTS:
         QCOMPARE(endRemoveRowsSpy.count(), 0);
         QCOMPARE(dataChangedSpy.count(), 0);
 
-        musicDb.insertTracksList(mNewTracks, mNewCovers);
+        musicDb.insertTracksList(mNewTracks);
 
         QCOMPARE(beginInsertRowsSpy.count(), 1);
         QCOMPARE(endInsertRowsSpy.count(), 1);
@@ -988,7 +984,7 @@ private Q_SLOTS:
         auto newTracks = DataTypes::ListTrackDataType();
         newTracks.push_back(newTrack);
 
-        musicDb.insertTracksList(newTracks, mNewCovers);
+        musicDb.insertTracksList(newTracks);
 
         QCOMPARE(beginInsertRowsSpy.count(), 1);
         QCOMPARE(endInsertRowsSpy.count(), 1);
@@ -1038,7 +1034,7 @@ private Q_SLOTS:
             newFiles.push_back(oneTrack.resourceURI());
         }
 
-        musicDb.insertTracksList(mNewTracks, mNewCovers);
+        musicDb.insertTracksList(mNewTracks);
 
         QCOMPARE(beginInsertRowsSpy.count(), 1);
         QCOMPARE(endInsertRowsSpy.count(), 1);
@@ -1055,11 +1051,7 @@ private Q_SLOTS:
         auto newTracks = DataTypes::ListTrackDataType();
         newTracks.push_back(newTrack);
 
-        auto newCover = QUrl::fromLocalFile(QStringLiteral("album5"));
-        auto newCovers = QHash<QString, QUrl>();
-        newCovers[QStringLiteral("album5")] = newCover;
-
-        musicDb.insertTracksList(newTracks, newCovers);
+        musicDb.insertTracksList(newTracks);
 
         QCOMPARE(beginInsertRowsSpy.count(), 2);
         QCOMPARE(endInsertRowsSpy.count(), 2);
@@ -1104,7 +1096,7 @@ private Q_SLOTS:
             newFiles.push_back(oneTrack.resourceURI());
         }
 
-        musicDb.insertTracksList(mNewTracks, mNewCovers);
+        musicDb.insertTracksList(mNewTracks);
 
         beginInsertRowsSpy.wait();
 
@@ -1167,7 +1159,7 @@ private Q_SLOTS:
             newFiles.push_back(oneTrack.resourceURI());
         }
 
-        musicDb.insertTracksList(mNewTracks, mNewCovers);
+        musicDb.insertTracksList(mNewTracks);
 
         beginInsertRowsSpy.wait();
 
@@ -1185,7 +1177,7 @@ private Q_SLOTS:
         {QUrl::fromLocalFile(QStringLiteral("file://image$23"))}, 5, true,
         {}, QStringLiteral("composer1"), QStringLiteral("lyricist1"), false};
 
-        musicDb.insertTracksList({newTrack}, mNewCovers);
+        musicDb.insertTracksList({newTrack});
 
         beginInsertRowsSpy.wait();
 
@@ -1244,7 +1236,7 @@ private Q_SLOTS:
             newFiles.push_back(oneTrack.resourceURI());
         }
 
-        musicDb.insertTracksList(mNewTracks, mNewCovers);
+        musicDb.insertTracksList(mNewTracks);
 
         beginInsertRowsSpy.wait();
 
@@ -1305,7 +1297,7 @@ private Q_SLOTS:
             newFiles.push_back(oneTrack.resourceURI());
         }
 
-        musicDb.insertTracksList(mNewTracks, mNewCovers);
+        musicDb.insertTracksList(mNewTracks);
 
         beginInsertRowsSpy.wait();
 
@@ -1367,7 +1359,7 @@ private Q_SLOTS:
             newFiles.push_back(oneTrack.resourceURI());
         }
 
-        musicDb.insertTracksList(mNewTracks, mNewCovers);
+        musicDb.insertTracksList(mNewTracks);
 
         beginInsertRowsSpy.wait();
 
@@ -1411,7 +1403,7 @@ private Q_SLOTS:
         QCOMPARE(modelResetSpy.count(), 0);
         QCOMPARE(dataChangedSpy.count(), 0);
 
-        musicDb.insertTracksList(mNewTracks, mNewCovers);
+        musicDb.insertTracksList(mNewTracks);
 
         QCOMPARE(artistsModel.rowCount(), 0);
         QCOMPARE(beginInsertRowsSpy.count(), 0);
@@ -1441,28 +1433,46 @@ private Q_SLOTS:
         QCOMPARE(modelResetSpy.count(), 0);
         QCOMPARE(dataChangedSpy.count(), 0);
 
-        auto newTracks = DataTypes::ListTrackDataType();
+        const DataTypes::ListTrackDataType newTracks = {{true,
+                                                         QStringLiteral("$31"),
+                                                         QStringLiteral("0"),
+                                                         QStringLiteral("track12"),
+                                                         QStringLiteral("artist1"),
+                                                         QStringLiteral("album1"),
+                                                         QStringLiteral("Various Artists"),
+                                                         12,
+                                                         1,
+                                                         QTime::fromMSecsSinceStartOfDay(31),
+                                                         {QUrl::fromLocalFile(QStringLiteral("/$31"))},
+                                                         QDateTime::fromMSecsSinceEpoch(31),
+                                                         {QUrl::fromLocalFile(QStringLiteral("album1"))},
+                                                         5,
+                                                         true,
+                                                         QStringLiteral("genre4"),
+                                                         QStringLiteral("composer4"),
+                                                         QStringLiteral("lyricist4"),
+                                                         true},
+                                                        {true,
+                                                         QStringLiteral("$32"),
+                                                         QStringLiteral("0"),
+                                                         QStringLiteral("track13"),
+                                                         QStringLiteral("artist3"),
+                                                         QStringLiteral("album3"),
+                                                         QStringLiteral("artist3"),
+                                                         13,
+                                                         1,
+                                                         QTime::fromMSecsSinceStartOfDay(32),
+                                                         {QUrl::fromLocalFile(QStringLiteral("/$32"))},
+                                                         QDateTime::fromMSecsSinceEpoch(32),
+                                                         {QUrl::fromLocalFile(QStringLiteral("album3"))},
+                                                         4,
+                                                         true,
+                                                         QStringLiteral("genre3"),
+                                                         QStringLiteral("composer3"),
+                                                         QStringLiteral("lyricist3"),
+                                                         false}};
 
-        newTracks = {{true, QStringLiteral("$31"), QStringLiteral("0"), QStringLiteral("track12"),
-                      QStringLiteral("artist1"), QStringLiteral("album1"), QStringLiteral("Various Artists"),
-                      12, 1, QTime::fromMSecsSinceStartOfDay(31),
-                      {QUrl::fromLocalFile(QStringLiteral("/$31"))},
-                      QDateTime::fromMSecsSinceEpoch(31),
-                      {QUrl::fromLocalFile(QStringLiteral("album1"))}, 5, true,
-                      QStringLiteral("genre4"), QStringLiteral("composer4"), QStringLiteral("lyricist4"), true},
-                     {true, QStringLiteral("$32"), QStringLiteral("0"), QStringLiteral("track13"),
-                      QStringLiteral("artist3"), QStringLiteral("album3"), QStringLiteral("artist3"),
-                      13, 1, QTime::fromMSecsSinceStartOfDay(32),
-                      {QUrl::fromLocalFile(QStringLiteral("/$32"))},
-                      QDateTime::fromMSecsSinceEpoch(32),
-                      {QUrl::fromLocalFile(QStringLiteral("album3"))}, 4, true,
-                      QStringLiteral("genre3"), QStringLiteral("composer3"), QStringLiteral("lyricist3"), false}};
-
-        auto newCovers = mNewCovers;
-        newCovers[QStringLiteral("file:///$31")] = QUrl::fromLocalFile(QStringLiteral("album1"));
-        newCovers[QStringLiteral("file:///$32")] = QUrl::fromLocalFile(QStringLiteral("album3"));
-
-        musicDb.insertTracksList(newTracks, newCovers);
+        musicDb.insertTracksList(newTracks);
 
         beginInsertRowsSpy.wait();
 
@@ -1503,13 +1513,7 @@ private Q_SLOTS:
         QCOMPARE(endRemoveRowsSpy.count(), 0);
         QCOMPARE(dataChangedSpy.count(), 0);
 
-        auto newFiles = QList<QUrl>();
-        const auto &constNewTracks = mNewTracks;
-        for (const auto &oneTrack : constNewTracks) {
-            newFiles.push_back(oneTrack.resourceURI());
-        }
-
-        musicDb.insertTracksList(mNewTracks, mNewCovers);
+        musicDb.insertTracksList(mNewTracks);
 
         QCOMPARE(beginInsertRowsSpy.count(), 0);
         QCOMPARE(endInsertRowsSpy.count(), 0);
@@ -1542,7 +1546,7 @@ private Q_SLOTS:
                 QUrl::fromLocalFile(QStringLiteral("album1")), 5, true,
         {}, QStringLiteral("composer1"), QStringLiteral("lyricist1"), false};
 
-        musicDb.insertTracksList({newTrack}, mNewCovers);
+        musicDb.insertTracksList({newTrack});
 
         QCOMPARE(albumsModel.rowCount(), 5);
         QCOMPARE(beginInsertRowsSpy.count(), 2);
